@@ -1,7 +1,7 @@
 package Bencher::Scenario::DataSah::Startup;
 
-our $DATE = '2016-05-15'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-05-16'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 our $scenario = {
     summary => 'Benchmark startup overhead of loading Data::Sah and generating validators',
@@ -31,7 +31,7 @@ Bencher::Scenario::DataSah::Startup - Benchmark startup overhead of loading Data
 
 =head1 VERSION
 
-This document describes version 0.04 of Bencher::Scenario::DataSah::Startup (from Perl distribution Bencher-Scenarios-DataSah), released on 2016-05-15.
+This document describes version 0.05 of Bencher::Scenario::DataSah::Startup (from Perl distribution Bencher-Scenarios-DataSah), released on 2016-05-16.
 
 =head1 SYNOPSIS
 
@@ -84,13 +84,13 @@ Benchmark with default options (C<< bencher -m DataSah::Startup >>):
  +---------------------+-----------+-----------+------------+---------+---------+
  | participant         | rate (/s) | time (ms) | vs_slowest | errors  | samples |
  +---------------------+-----------+-----------+------------+---------+---------+
- | genval_str_5typical | 25        | 40        | 1          | 0.00013 | 20      |
- | genval_str_date     | 26        | 38        | 1          | 0.00013 | 20      |
- | genval_str_int      | 27        | 37        | 1.1        | 9.9e-05 | 20      |
- | genval_bool_int     | 27        | 37        | 1.1        | 0.00017 | 21      |
- | load_dsah+get_plc   | 49        | 21        | 1.9        | 6.6e-05 | 20      |
- | load_dsah           | 1.4e+02   | 7         | 5.7        | 2.8e-05 | 21      |
- | perl                | 4.3e+02   | 2.3       | 17         | 9.6e-06 | 21      |
+ | genval_str_5typical | 24        | 41        | 1          | 0.00018 | 20      |
+ | genval_bool_int     | 26        | 38        | 1.1        | 9e-05   | 20      |
+ | genval_str_date     | 26        | 38        | 1.1        | 0.00013 | 20      |
+ | genval_str_int      | 26        | 38        | 1.1        | 0.00016 | 20      |
+ | load_dsah+get_plc   | 49        | 20        | 2          | 9e-05   | 20      |
+ | load_dsah           | 1.4e+02   | 7.3       | 5.6        | 4.4e-05 | 20      |
+ | perl                | 3.9e+02   | 2.6       | 16         | 1.2e-05 | 20      |
  +---------------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
