@@ -1,7 +1,7 @@
 package Bencher::Scenario::DataSah::gen_validator;
 
-our $DATE = '2016-05-15'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-05-16'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 my $return_types = ['bool', 'str', 'full'];
 
@@ -39,7 +39,7 @@ Bencher::Scenario::DataSah::gen_validator - Benchmark validator generation
 
 =head1 VERSION
 
-This document describes version 0.04 of Bencher::Scenario::DataSah::gen_validator (from Perl distribution Bencher-Scenarios-DataSah), released on 2016-05-15.
+This document describes version 0.05 of Bencher::Scenario::DataSah::gen_validator (from Perl distribution Bencher-Scenarios-DataSah), released on 2016-05-16.
 
 =head1 SYNOPSIS
 
@@ -102,27 +102,27 @@ Benchmark with default options (C<< bencher -m DataSah::gen_validator >>):
  +--------------------------------------------------+-----------------+-----------+-----------+------------+---------+---------+
  | dataset                                          | arg_return_type | rate (/s) | time (ms) | vs_slowest | errors  | samples |
  +--------------------------------------------------+-----------------+-----------+-----------+------------+---------+---------+
- | ["array","elems",["int*","str*","float*","re*"]] | str             | 3.1e+02   | 3.2       | 1          | 9.6e-06 | 20      |
- | ["array","elems",["int*","str*","float*","re*"]] | full            | 3.1e+02   | 3.2       | 1          | 3.4e-06 | 20      |
- | ["array","elems",["int*","str*","float*","re*"]] | bool            | 3.4e+02   | 2.9       | 1.1        | 1.3e-05 | 21      |
- | ["array","of",["str","min_len",1,"max_len",10]]  | full            | 593       | 1.69      | 1.91       | 1.7e-06 | 20      |
- | ["array","of",["str","min_len",1,"max_len",10]]  | str             | 6.1e+02   | 1.6       | 2          | 3.1e-06 | 20      |
- | ["array","of",["str","min_len",1,"max_len",10]]  | bool            | 6.7e+02   | 1.5       | 2.2        | 4.2e-06 | 20      |
- | ["str","min_len",1,"max_len",10]                 | str             | 1e+03     | 0.96      | 3.4        | 2e-06   | 20      |
- | ["str","min_len",1,"max_len",10]                 | full            | 1.06e+03  | 0.945     | 3.41       | 4.3e-07 | 20      |
- | ["str","min_len",1,"max_len",10]                 | bool            | 1.1e+03   | 0.88      | 3.7        | 2.5e-06 | 20      |
- | ["str","len",8]                                  | full            | 1.2e+03   | 0.83      | 3.9        | 1.1e-06 | 22      |
- | ["str","len",8]                                  | str             | 1.25e+03  | 0.801     | 4.03       | 4.3e-07 | 20      |
- | date                                             | full            | 1.3e+03   | 0.77      | 4.2        | 9.1e-07 | 20      |
- | date                                             | str             | 1.36e+03  | 0.737     | 4.38       | 4.3e-07 | 20      |
- | ["str","len",8]                                  | bool            | 1.37e+03  | 0.731     | 4.41       | 6.4e-07 | 20      |
- | date                                             | bool            | 1.4e+03   | 0.71      | 4.5        | 2e-06   | 20      |
- | str*                                             | str             | 1.4e+03   | 0.7       | 4.6        | 4e-06   | 20      |
- | str*                                             | full            | 1.45e+03  | 0.688     | 4.69       | 2.1e-07 | 20      |
- | str*                                             | bool            | 1.6e+03   | 0.61      | 5.3        | 8.5e-07 | 20      |
- | str                                              | str             | 1.64e+03  | 0.61      | 5.29       | 4.3e-07 | 20      |
- | str                                              | full            | 1.66e+03  | 0.604     | 5.34       | 4.3e-07 | 20      |
- | str                                              | bool            | 1.7e+03   | 0.59      | 5.5        | 2.7e-06 | 20      |
+ | ["array","elems",["int*","str*","float*","re*"]] | full            | 307       | 3.25      | 1          | 1.1e-06 | 20      |
+ | ["array","elems",["int*","str*","float*","re*"]] | str             | 314       | 3.19      | 1.02       | 6.4e-07 | 20      |
+ | ["array","elems",["int*","str*","float*","re*"]] | bool            | 347       | 2.88      | 1.13       | 9.6e-07 | 20      |
+ | ["array","of",["str","min_len",1,"max_len",10]]  | full            | 593       | 1.69      | 1.93       | 9.1e-07 | 20      |
+ | ["array","of",["str","min_len",1,"max_len",10]]  | str             | 604       | 1.65      | 1.97       | 8.8e-07 | 21      |
+ | ["array","of",["str","min_len",1,"max_len",10]]  | bool            | 669       | 1.5       | 2.18       | 1.2e-06 | 20      |
+ | ["str","min_len",1,"max_len",10]                 | full            | 1.04e+03  | 0.965     | 3.37       | 8.5e-07 | 20      |
+ | ["str","min_len",1,"max_len",10]                 | str             | 1.06e+03  | 0.947     | 3.44       | 4.8e-07 | 20      |
+ | ["str","min_len",1,"max_len",10]                 | bool            | 1.17e+03  | 0.858     | 3.79       | 6.4e-07 | 20      |
+ | ["str","len",8]                                  | full            | 1.24e+03  | 0.809     | 4.02       | 2.1e-07 | 20      |
+ | ["str","len",8]                                  | str             | 1.25e+03  | 0.797     | 4.08       | 6.4e-07 | 20      |
+ | date                                             | full            | 1.31e+03  | 0.766     | 4.25       | 6.4e-07 | 20      |
+ | date                                             | str             | 1.33e+03  | 0.754     | 4.32       | 4.3e-07 | 20      |
+ | ["str","len",8]                                  | bool            | 1.38e+03  | 0.722     | 4.51       | 4.8e-07 | 20      |
+ | date                                             | bool            | 1.42e+03  | 0.706     | 4.61       | 2.1e-07 | 20      |
+ | str*                                             | full            | 1.43e+03  | 0.701     | 4.65       | 4.3e-07 | 20      |
+ | str*                                             | str             | 1.46e+03  | 0.686     | 4.75       | 4.3e-07 | 20      |
+ | str*                                             | bool            | 1.62e+03  | 0.619     | 5.26       | 2.1e-07 | 20      |
+ | str                                              | full            | 1.62e+03  | 0.617     | 5.27       | 4.3e-07 | 20      |
+ | str                                              | str             | 1.65e+03  | 0.605     | 5.38       | 4.2e-07 | 21      |
+ | str                                              | bool            | 1.8e+03   | 0.56      | 5.9        | 6.2e-07 | 21      |
  +--------------------------------------------------+-----------------+-----------+-----------+------------+---------+---------+
 
 
@@ -131,8 +131,8 @@ Benchmark module startup overhead (C<< bencher -m DataSah::gen_validator --modul
  +---------------------+-----------+------------------------+------------+---------+---------+
  | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
  +---------------------+-----------+------------------------+------------+---------+---------+
- | Data::Sah           | 7.1       | 4.6                    | 1          | 2e-05   | 20      |
- | perl -e1 (baseline) | 2.5       | 0                      | 2.9        | 9.8e-06 | 21      |
+ | Data::Sah           | 7.1       | 4.5                    | 1          | 1.7e-05 | 20      |
+ | perl -e1 (baseline) | 2.6       | 0                      | 2.7        | 5.2e-06 | 20      |
  +---------------------+-----------+------------------------+------------+---------+---------+
 
 =head1 DESCRIPTION
