@@ -1,7 +1,7 @@
 package Bencher::Scenario::DataSah::normalize_schema;
 
-our $DATE = '2016-05-15'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-05-16'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 # TODO: benchmark normalize_clset
 
@@ -68,7 +68,7 @@ Bencher::Scenario::DataSah::normalize_schema - Benchmark normalizing Sah schema
 
 =head1 VERSION
 
-This document describes version 0.04 of Bencher::Scenario::DataSah::normalize_schema (from Perl distribution Bencher-Scenarios-DataSah), released on 2016-05-15.
+This document describes version 0.05 of Bencher::Scenario::DataSah::normalize_schema (from Perl distribution Bencher-Scenarios-DataSah), released on 2016-05-16.
 
 =head1 SYNOPSIS
 
@@ -124,15 +124,15 @@ Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (
 
 Benchmark with default options (C<< bencher -m DataSah::normalize_schema >>):
 
- +--------------+------------+-----------+------------+---------+---------+
- | dataset      | rate (/s)  | time (μs) | vs_slowest | errors  | samples |
- +--------------+------------+-----------+------------+---------+---------+
- | array5       | 1.77e+05   | 5.64      | 1          | 1.7e-09 | 20      |
- | array3       | 2.4245e+05 | 4.1246    | 1.3679     | 4e-11   | 21      |
- | array1       | 4.59e+05   | 2.18      | 2.59       | 8.3e-10 | 20      |
- | str_wildcard | 7.4e+05    | 1.35      | 4.17       | 1.3e-09 | 20      |
- | str          | 9.31e+05   | 1.07      | 5.25       | 3.9e-10 | 23      |
- +--------------+------------+-----------+------------+---------+---------+
+ +--------------+-----------+-----------+------------+---------+---------+
+ | dataset      | rate (/s) | time (μs) | vs_slowest | errors  | samples |
+ +--------------+-----------+-----------+------------+---------+---------+
+ | array5       | 1.52e+05  | 6.6       | 1          | 3.3e-09 | 20      |
+ | array3       | 2.1e+05   | 4.8       | 1.4        | 5e-09   | 20      |
+ | array1       | 4e+05     | 2.5       | 2.64       | 8.3e-10 | 20      |
+ | str_wildcard | 681537    | 1.46727   | 4.49502    | 0       | 20      |
+ | str          | 861981    | 1.16012   | 5.68512    | 0       | 20      |
+ +--------------+-----------+-----------+------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m DataSah::normalize_schema --module-startup >>):
@@ -140,8 +140,8 @@ Benchmark module startup overhead (C<< bencher -m DataSah::normalize_schema --mo
  +----------------------+-----------+------------------------+------------+---------+---------+
  | participant          | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
  +----------------------+-----------+------------------------+------------+---------+---------+
- | Data::Sah::Normalize | 5         | 2.5                    | 1          | 2.3e-05 | 20      |
- | perl -e1 (baseline)  | 2.5       | 0                      | 2          | 3.8e-06 | 20      |
+ | Data::Sah::Normalize | 5.2       | 2.5                    | 1          | 3.4e-05 | 20      |
+ | perl -e1 (baseline)  | 2.7       | 0                      | 2          | 2.5e-05 | 21      |
  +----------------------+-----------+------------------------+------------+---------+---------+
 
 =head1 DESCRIPTION
